@@ -7,13 +7,21 @@ def exists(path):
 		return False
 		
 class File:
-	def __init__(self, path):
+	def __init__(self, fname, path, ext):
+		self.__fname = fname
 		self.__path = path
+		self.__ext = ext
 		self.__is_printed = False
 		
 	def path(self):
 		return self.__path
 		
+	def ext(self):
+		return self.__ext
+		
+	def absPath(self):
+		return self.__path + self.__fname + self.__ext
+		
 	def isPrintable(self):
 		return self.__is_printed
 	
